/** @module babel-preset-jaid
 */
declare module "babel-preset-jaid" {
    /**
     * @typedef {Object} options
     * @prop {boolean} [react=false] If `true` or typeof `string`, `react`-related plugins and presets are included. If `react-, `react-dom`-related plugins and presets are also included.
     * @prop {boolean} [runtime=true] If `true`, `@babel/plugin-transform-runtime` will be applied.
     * @prop {boolean|Object} [minify=true] If `false`, `babel-minify` won't be applied to production builds. If `true`, `babel-fy` will be applied with `{removeConsole: false, removeDebugger: true}` as configuration. If typeof `object`, this will bed as `babel-minify` config.
     * @prop {Object} [envOptions=null] If typeof `object`, this will be used as options for `@babel/preset-env`.
     * @prop {boolean} [flow=false] If `true`, support Facebook Flow.
     * @prop {boolean} [typescript=false] If `true`, support Microsoft TypeScript.
     * @prop {boolean} [aotLoader=true] If `true`, `aot-loader/babel` will be applied
     * @prop {boolean} [legacyDecorators=true] If `true`, `plugin-proposal-decorators` will have `lecacy: true` and `plugin-proposal-class-properties` will have `loose: true`
     * @prop {boolean} [outputConfig = false] If `true`, the generated Babel config will be written to `./dist/babel-preset-jaid/config.json` (can be also activated with environment variable outputBabelPresetJaid=1)
     */
    export type options = {
        react?: boolean;
        runtime?: boolean;
        minify?: boolean | any;
        envOptions?: any;
        flow?: boolean;
        typescript?: boolean;
        aotLoader?: boolean;
        legacyDecorators?: boolean;
        outputConfig?: boolean;
    };
    /**
     * @function default
     * @param {object} api Babel api instance
     * @param {options} options
     */
    export default function(api: any, options: options): void;
}